@@ -1,15 +1,15 @@
 /** ===========================================================
  * @file
  *
- * This file is a part of kipi-plugins project
- * <a href="http://www.digikam.org">http://www.digikam.org</a>
+ * This file is a part of KDE project
+ *
  *
  * @date   2009-11-21
  * @brief  kipi host test application
  *
  * @author Copyright (C) 2009-2010 by Michael G. Hansen
  *         <a href="mailto:mike at mghansen dot de">mike at mghansen dot de</a>
- * @author Copyright (C) 2011-2016 by Gilles Caulier
+ * @author Copyright (C) 2011-2017 by Gilles Caulier
  *         <a href="mailto:caulier dot gilles at gmail dot com">caulier dot gilles at gmail dot com</a>
  *
  * This program is free software; you can redistribute it
@@ -49,7 +49,7 @@ public:
     KipiUploadWidget(KipiInterface* const interface, QWidget* const parent);
     virtual ~KipiUploadWidget();
 
-    virtual ImageCollection selectedImageCollection() const;
+    ImageCollection selectedImageCollection() const Q_DECL_OVERRIDE;
 
 public Q_SLOTS:
 
